using System;
using System.Configuration;
using System.IO;

namespace ModelFileManager
{
	static public class Common
	{
		public const int MAX_MODELS = 255;

		// ----------------------------------------------------------------------------------------------------------------------

		public static string GetModelName(string modelfile)
		{
			string result = "";

			if (File.Exists(modelfile))
			{
				result = "NONE";
				using (StreamReader sr = new StreamReader(modelfile))
				{
					string nextline = sr.ReadLine();
					if (nextline.ToUpper().StartsWith("NAME"))
						result = nextline.Substring(nextline.IndexOf("=") + 1);
				}
			}

			return result;
		}

		// ----------------------------------------------------------------------------------------------------------------------

		public static void SetModelName(string modelFile, string newName)
		{
			string tempFile = modelFile.Replace(".ini", ".new");

			if (File.Exists(modelFile))
			{
				// open a reader to read the original file
				using (StreamReader sr = new StreamReader(modelFile))
				{
					// open a writer to save the new file content
					using (StreamWriter sw = new StreamWriter(tempFile))
					{
						// scan the whole file
						while (sr.Peek() > 0)
						{
							// replace the name line
							string nextLine = sr.ReadLine();
							if (nextLine.ToUpper().StartsWith("NAME"))
								sw.Write("name=" + newName + "\n");
							else
								sw.Write(nextLine + "\n");
						}
					}
				}

				// remove the original file
				File.Delete(modelFile);
				// copy in the new file
				File.Move(tempFile, modelFile);
			}
		}

		// ----------------------------------------------------------------------------------------------------------------------

		public static void WriteError(string location, Exception ex)
		{
			string ErrorFile = "errors.txt";
			using (StreamWriter sw = new StreamWriter(ErrorFile, false))
			{
				sw.WriteLine("Error occurred " + DateTime.Now.ToShortDateString() + " " + DateTime.Now.ToShortTimeString());
				sw.WriteLine("---------------------------------------------------------------------------------------------");
				sw.WriteLine("Location:  " + location);
				sw.WriteLine("Exception: " + ex.Message + ex.StackTrace);
				sw.WriteLine("---------------------------------------------------------------------------------------------");
			}
		}
	
		// ----------------------------------------------------------------------------------------------------------------------

		public static void MessageBoxInfo(Gtk.Window parent, string content)
		{
			Gtk.MessageDialog md = new Gtk.MessageDialog (parent, Gtk.DialogFlags.Modal | Gtk.DialogFlags.DestroyWithParent, Gtk.MessageType.Info, Gtk.ButtonsType.Ok, content);
			md.Run();
			md.Destroy ();
			md.Dispose ();
		}

		// ----------------------------------------------------------------------------------------------------------------------

		public static void MessageBoxError(Gtk.Window parent, string content)
		{
			Gtk.MessageDialog md = new Gtk.MessageDialog (parent, Gtk.DialogFlags.Modal | Gtk.DialogFlags.DestroyWithParent, Gtk.MessageType.Error, Gtk.ButtonsType.Ok, content);
			md.Run();
			md.Destroy ();
			md.Dispose ();
		}
	
		// ----------------------------------------------------------------------------------------------------------------------

		public static bool MessageBoxConfirm(Gtk.Window parent, string content)
		{
			bool result = false;

			Gtk.MessageDialog md = new Gtk.MessageDialog (parent, Gtk.DialogFlags.Modal | Gtk.DialogFlags.DestroyWithParent, Gtk.MessageType.Question, Gtk.ButtonsType.OkCancel, content);
			md.Title = "Confirm";
			Gtk.ResponseType tp = (Gtk.ResponseType)md.Run();
			result = (tp == Gtk.ResponseType.Ok);
			md.Destroy ();
			md.Dispose ();

			return result;
		}

		// ----------------------------------------------------------------------------------------------------------------------

		public static bool MessageBoxYesNo(Gtk.Window parent, string content)
		{
			bool result = false;

			Gtk.MessageDialog md = new Gtk.MessageDialog (parent, Gtk.DialogFlags.Modal | Gtk.DialogFlags.DestroyWithParent, Gtk.MessageType.Question, Gtk.ButtonsType.YesNo, content);
			md.Title = "Confirm";
			Gtk.ResponseType tp = (Gtk.ResponseType)md.Run();
			result = (tp == Gtk.ResponseType.Yes);
			md.Destroy ();
			md.Dispose ();

			return result;
		}

		// ----------------------------------------------------------------------------------------------------------------------
		public static string ConfigAppSetting(System.Configuration.Configuration config, string keyString)
		{
			string result = "";

			if (config == null)
				result = ConfigurationManager.AppSettings[keyString];
			else
				result = config.AppSettings.Settings[keyString].Value;

			return result;
		}

	}
}

